]> de.git.xonotic.org Git - xonotic/darkplaces.git/commitdiff
remove PRECACHE_PIC_NOCLAMP because it currently has no chance to work
authordivverent <divverent@d7cf8633-e32d-0410-b094-e92efae38249>
Tue, 24 Jan 2012 21:47:10 +0000 (21:47 +0000)
committerRudolf Polzer <divverent@alientrap.org>
Thu, 26 Jan 2012 17:49:03 +0000 (18:49 +0100)
git-svn-id: svn://svn.icculus.org/twilight/trunk/darkplaces@11658 d7cf8633-e32d-0410-b094-e92efae38249
::stable-branch::merge=d101875d68b898ea13f69e0bede0e1b24f9856f0

gl_draw.c

index 127a0b377c8c30fc299255750095d971a8c78cae..589140e26fc57305a3f5b2749aec2f95b9bb42d5 100644 (file)
--- a/gl_draw.c
+++ b/gl_draw.c
@@ -343,7 +343,7 @@ cachepic_t *Draw_CachePic_Flags(const char *path, unsigned int cachepicflags)
                        // if it was created (or replaced) by Draw_NewPic, just return it
                        if(pic->flags & CACHEPICFLAG_NEWPIC)
                                return pic;
-                       if (!((pic->texflags ^ texflags) & ~(TEXF_COMPRESS))) // ignore TEXF_COMPRESS when comparing, because fallback pics remove the flag
+                       if (!((pic->texflags ^ texflags) & ~(TEXF_COMPRESS | TEXF_MIPMAP))) // ignore TEXF_COMPRESS when comparing, because fallback pics remove the flag, and ignore TEXF_MIPMAP because QC specifies that
                        {
                                if(!(cachepicflags & CACHEPICFLAG_NOTPERSISTENT))
                                {